/*
 * spi.h
 *
 * this spi library provides SPI functionality
 *
 * it is implemented using:
 *
 * spi.h	this file
 * spi.c	the library itself
 *
 * =============================================================================================
 *  Created on: 21 Aug 2011
 *      Author: Mike McPherson (mmcp42)
 *       email: mmcp42@yahoo.com
 *     version: 1.01
 * =============================================================================================
 *  License - usual free stuff - caveat emptor
 *  if you like it - buy me a beer
 *  if you don't - then I don't know you!
 *
 *  if you do make changes - do let me know so I can keep it up to date
 * =============================================================================================
 *
 * functions supported:
 *
 * uint8 spiDeselect(usartID);
 * uint8 spiInit(uint8 usartID, uint8 alternate, uint8 polarity, uint8 phase, uint8 bitOrder);
 * uint8 spiReadByte(uint8 usartID);
 * uint8 spiReadData(uint8 usartID, uint8* buffer, uint8 size);
 * uint8 spiSelect(usartID);
 * uint8 spiSetSpeed(usartID, speed);
 * uint8 spiSendCommand(uint8 usartID, uint8 command);
 * void spiShowBuffer( uint8 *buffer, uint16 size);
 * uint8 spiWriteData(uint8 usartID, uint8* buffer, uint8 size);
 * =============================================================================================
 * uint8 spiDeselect(usartID);
 *
 * deselect SPI device, sets SS HIGH
 * returns 1 for success, 0 for error (usually parameter value out of range)
 * =============================================================================================
 * uint8 spiInit(uint8 usartID, uint8 alternate, uint8 polarity, uint8 phase, uint8 bitOrder);
 * initialise USART0 or USART1
 *
 * either alternate location may be set
 * polarity may be positive or negative
 * phase may be positive or negative
 * bitOrder may be LSB or MSB first
 *
 * returns 1 for success, 0 for error (usually parameter value out of range)
 * =============================================================================================
 * uint8 spiReadByte(uint8 usartID);
 *
 * read one byte of data from SPI
 * returns data read
 * =============================================================================================
 * uint8 spiReadData(uint8 usartID, uint8* buffer, uint8 size);
 *
 * read data from SPI into a buffer
 * returns number of characters read
 * =============================================================================================
 * uint8 spiSelect(usartID);
 *
 * select SPI device, sets SS LOW
 * returns 1 for success, 0 for error (usually parameter value out of range)
 * =============================================================================================
 * uint16 spiSetSpeed(uint8 usartID, uint16 speed);
 *
 * set SPI speed in KHz, maximum is 13MHz (26MHz clock/2)
 * speed = 0 means set maximum speed
 * allowable values:
 * 		400 KHz
 *
 * returns speed for success, 0 for error
 * =============================================================================================
 * void spiShowBuffer( uint8 *buffer, uint16 size);
 *
 * dump contents of buffer
 * =============================================================================================
 * uint8 spiWriteData(uint8 usartID, uint8* buffer, uint8 size);
 *
 * writes data from buffer to SPI
 * returns number of characters written
 * =============================================================================================
 *
 */

#ifndef SPI_H_
#define SPI_H_

#include <wixel.h>
#include <usb.h>
#include <usb_com.h>

// define SPI_DEBUG to generate printf messages
//=============================================
#define SPI_DEBUG

#ifdef SPI_DEBUG
#include <stdio.h>
#define debug printf
#else
#define debug //
#endif

#define spiUsart0 0
#define spiUsart1 1
#define spiAlternate1 1
#define spiAlternate2 2
#define spiPhaseN 0
#define spiPhaseP 1
#define spiPolarityN 0
#define spiPolarityP 1
#define spiBitOrderM 0
#define spiBitOrderL 1

#define HIGH 1
#define LOW 0
#define TIMEOUT 1000

uint8  spiDeselect(uint8 usartID);
uint8  spiInit(uint8 usartID, uint8 alternate, uint8 polarity, uint8 phase, uint8 bitOrder);
uint8  spiReadByte(uint8 usartID);
uint16 spiReadData(uint8 usartID, uint8* buffer, uint16 size);
uint8  spiSelect(uint8 usartID);
uint16 spiSetSpeed(uint8 usartID, uint16 speed);
void   spiShowBuffer( uint8 *buffer, uint16 size);
uint16 spiWriteData(uint8 usartID, uint8* buffer, uint16 size);

#endif /* SPI_H_ */
